onFullscreenFixLandscape property
If it is true, when entering the fullscreen it will be fixed
in landscape mode and it will not be possible to rotate it in portrait.
If it is false, you can rotate the entire screen in any position.
Implementation
final bool onFullscreenFixLandscape;